@@ -427,7 +427,7 @@ class HealthServicerImpl(HealthServicer):
 class LoggingInterceptor(grpc.ServerInterceptor):
     def intercept_service(self, continuation, handler_call_details):
         if handler_call_details.method != "/grpc.health.v1.Health/Check":
-            logger.info(handler_call_details)
+            logger.debug(handler_call_details)
         return continuation(handler_call_details)
 
 
